are_intervals_contiguous

Function are_intervals_contiguous 

pub fn are_intervals_contiguous(intervals: &[(u64, u64)]) -> bool
Checks if intervals are contiguous (adjacent with no gaps).

Intervals are contiguous if, when sorted by start time, each interval’s start timestamp is exactly one more than the previous interval’s end timestamp.